@@ -1487,7 +1487,16 @@ public:
       return;
     }
 
-    path.SetNativeDir(Lum::Base::Path::GetHome());
+    std::wstring envdir;
+
+    envdir=Lum::Base::Path::GetDirFromEnvironment("MYDOCSDIR");
+    if (!envdir.empty()) {
+      path.SetNativeDir(envdir);
+    }
+    else {
+      path.SetNativeDir(Lum::Base::Path::GetHome());
+    }
+
     path.SetBaseName(name+L".kml");
 
     file=path.GetPath();
@@ -1734,7 +1743,7 @@ public:
         t+=L"\u00b1"+DoubleToString(data.GetTrackDev());
       }
 
-      t+=+L"\u00b0";
+      t+=L"\u00b0";
 
       track->Set(t);
 
@@ -1753,7 +1762,7 @@ public:
         c+=L"\u00b1"+DoubleToString(data.GetClimbDev());
       }
 
-      c+=+L"m";
+      c+=L"m";
 
       climb->Set(c);
     }
